@@ -1,13 +1,19 @@
+//! Platform-specific code.
+use std::{
+    cmp::Ordering,
+    fmt,
+    fmt::{Display, Formatter},
+    str::FromStr,
+};
+
 use itertools::Itertools;
 use serde::{Deserializer, Serializer};
-use std::cmp::Ordering;
-use std::fmt::Display;
-use std::{fmt, fmt::Formatter, str::FromStr};
 use strum::{EnumIter, IntoEnumIterator};
 use thiserror::Error;
 
 /// A platform supported by Conda.
 #[allow(missing_docs)]
+#[non_exhaustive] // The `Platform` enum is non-exhaustive to allow for future extensions without breaking changes.
 #[derive(EnumIter, Debug, Clone, Copy, Eq, PartialEq, Hash)]
 pub enum Platform {
     NoArch,
@@ -18,6 +24,7 @@ pub enum Platform {
     LinuxAarch64,
     LinuxArmV6l,
     LinuxArmV7l,
+    LinuxLoong64,
     LinuxPpc64le,
     LinuxPpc64,
     LinuxPpc,
@@ -52,6 +59,7 @@ impl Ord for Platform {
 
 /// Known architectures supported by Conda.
 #[allow(missing_docs)]
+#[non_exhaustive] // The `Arch` enum is non-exhaustive to allow for future extensions without breaking changes.
 #[derive(EnumIter, Debug, Clone, Copy, Eq, PartialEq, Hash)]
 pub enum Arch {
     X86,
@@ -62,6 +70,7 @@ pub enum Arch {
     Arm64,
     ArmV6l,
     ArmV7l,
+    Loong64,
     Ppc64le,
     Ppc64,
     Ppc,
@@ -95,6 +104,9 @@ impl Platform {
                 return Platform::LinuxArmV6l;
             }
 
+            #[cfg(target_arch = "loongarch64")]
+            return Platform::LinuxLoong64;
+
             #[cfg(all(target_arch = "powerpc64", target_endian = "little"))]
             return Platform::LinuxPpc64le;
 
@@ -122,7 +134,8 @@ impl Platform {
                 target_arch = "arm",
                 target_arch = "powerpc64",
                 target_arch = "powerpc",
-                target_arch = "s390x"
+                target_arch = "s390x",
+                target_arch = "loongarch64"
             )))]
             compile_error!("unsupported linux architecture");
         }
@@ -202,6 +215,7 @@ impl Platform {
                 | Platform::LinuxAarch64
                 | Platform::LinuxArmV6l
                 | Platform::LinuxArmV7l
+                | Platform::LinuxLoong64
                 | Platform::LinuxPpc64le
                 | Platform::LinuxPpc64
                 | Platform::LinuxPpc
@@ -225,6 +239,7 @@ impl Platform {
             | Platform::LinuxAarch64
             | Platform::LinuxArmV6l
             | Platform::LinuxArmV7l
+            | Platform::LinuxLoong64
             | Platform::LinuxPpc64le
             | Platform::LinuxPpc64
             | Platform::LinuxPpc
@@ -269,6 +284,7 @@ impl FromStr for Platform {
             "linux-aarch64" => Platform::LinuxAarch64,
             "linux-armv6l" => Platform::LinuxArmV6l,
             "linux-armv7l" => Platform::LinuxArmV7l,
+            "linux-loong64" => Platform::LinuxLoong64,
             "linux-ppc64le" => Platform::LinuxPpc64le,
             "linux-ppc64" => Platform::LinuxPpc64,
             "linux-ppc" => Platform::LinuxPpc,
@@ -301,6 +317,7 @@ impl From<Platform> for &'static str {
             Platform::LinuxAarch64 => "linux-aarch64",
             Platform::LinuxArmV6l => "linux-armv6l",
             Platform::LinuxArmV7l => "linux-armv7l",
+            Platform::LinuxLoong64 => "linux-loong64",
             Platform::LinuxPpc64le => "linux-ppc64le",
             Platform::LinuxPpc64 => "linux-ppc64",
             Platform::LinuxPpc => "linux-ppc",
@@ -323,12 +340,14 @@ impl From<Platform> for &'static str {
 impl Platform {
     /// Return the arch string for the platform
     /// The arch is usually the part after the `-` of the platform string.
-    /// Only for 32 and 64 bit platforms the arch is `x86` and `x86_64` respectively.
+    /// Only for 32 and 64 bit platforms the arch is `x86` and `x86_64`
+    /// respectively.
     pub fn arch(&self) -> Option<Arch> {
         match self {
             Platform::Unknown | Platform::NoArch => None,
             Platform::LinuxArmV6l => Some(Arch::ArmV6l),
             Platform::LinuxArmV7l => Some(Arch::ArmV7l),
+            Platform::LinuxLoong64 => Some(Arch::Loong64),
             Platform::LinuxPpc64le => Some(Arch::Ppc64le),
             Platform::LinuxPpc64 => Some(Arch::Ppc64),
             Platform::LinuxPpc => Some(Arch::Ppc),
@@ -403,6 +422,7 @@ impl FromStr for Arch {
             "arm64" => Arch::Arm64,
             "armv6l" => Arch::ArmV6l,
             "armv7l" => Arch::ArmV7l,
+            "loong64" => Arch::Loong64,
             "ppc64le" => Arch::Ppc64le,
             "ppc64" => Arch::Ppc64,
             "ppc" => Arch::Ppc,
@@ -429,6 +449,7 @@ impl From<Arch> for &'static str {
             Arch::Aarch64 => "aarch64",
             Arch::ArmV6l => "armv6l",
             Arch::ArmV7l => "armv7l",
+            Arch::Loong64 => "loong64",
             Arch::Ppc64le => "ppc64le",
             Arch::Ppc64 => "ppc64",
             Arch::Ppc => "ppc",
@@ -517,6 +538,7 @@ mod tests {
         assert_eq!(Platform::LinuxAarch64.arch(), Some(Arch::Aarch64));
         assert_eq!(Platform::LinuxArmV6l.arch(), Some(Arch::ArmV6l));
         assert_eq!(Platform::LinuxArmV7l.arch(), Some(Arch::ArmV7l));
+        assert_eq!(Platform::LinuxLoong64.arch(), Some(Arch::Loong64));
         assert_eq!(Platform::LinuxPpc64le.arch(), Some(Arch::Ppc64le));
         assert_eq!(Platform::LinuxPpc64.arch(), Some(Arch::Ppc64));
         assert_eq!(Platform::LinuxPpc.arch(), Some(Arch::Ppc));
