@@ -3,7 +3,7 @@
 use crate::package::FileMode;
 use crate::repo_data::RecordFromPath;
 use crate::repo_data_record::RepoDataRecord;
-use crate::{menuinst, PackageRecord};
+use crate::{menuinst, PackageName, PackageRecord};
 use rattler_digest::serde::SerializableHash;
 use serde::{Deserialize, Serialize};
 use serde_repr::{Deserialize_repr, Serialize_repr};
@@ -100,6 +100,13 @@ pub struct PathsEntry {
     pub prefix_placeholder: Option<String>,
 }
 
+impl PathsEntry {
+    /// Returns either `original_path` or `relative_path`.
+    pub fn path(&self) -> &PathBuf {
+        self.original_path.as_ref().unwrap_or(&self.relative_path)
+    }
+}
+
 /// Information about a single file installed for a package.
 ///
 /// This enum is similar to the [`crate::package::PathType`] enum. This enum includes more enum entries
@@ -329,6 +336,11 @@ impl PrefixRecord {
                 .collect()
         }
     }
+
+    /// Returns package name of a prefix record.
+    pub fn name(&self) -> &PackageName {
+        &self.repodata_record.package_record.name
+    }
 }
 
 impl FromStr for PrefixRecord {
