@@ -6,20 +6,20 @@ use std::{collections::HashSet, fmt, fmt::Formatter, hash::Hash, rc::Rc};
 use ahash::HashMap;
 use itertools::Itertools;
 use petgraph::{
+    Direction,
     graph::{DiGraph, EdgeIndex, EdgeReference, NodeIndex},
     visit::{Bfs, DfsPostOrder, EdgeRef},
-    Direction,
 };
 
 use crate::solver::variable_map::VariableOrigin;
 use crate::{
+    DependencyProvider, Interner, Requirement,
     internal::{
         arena::ArenaId,
         id::{ClauseId, SolvableId, SolvableOrRootId, StringId, VersionSetId},
     },
     runtime::AsyncRuntime,
-    solver::{clause::Clause, Solver},
-    DependencyProvider, Interner, Requirement,
+    solver::{Solver, clause::Clause},
 };
 
 /// Represents the cause of the solver being unable to find a solution
@@ -48,6 +48,8 @@ impl Conflict {
         &self,
         solver: &Solver<D, RT>,
     ) -> ConflictGraph {
+        let state = &solver.state;
+
         let mut graph = DiGraph::<ConflictNode, ConflictEdge>::default();
         let mut nodes: HashMap<SolvableOrRootId, NodeIndex> = HashMap::default();
         let mut excluded_nodes: HashMap<StringId, NodeIndex> = HashMap::default();
@@ -57,13 +59,13 @@ impl Conflict {
         let mut last_node_by_name = HashMap::default();
 
         for clause_id in &self.clauses {
-            let clause = &solver.clauses.kinds[clause_id.to_usize()];
+            let clause = &state.clauses.kinds[clause_id.to_usize()];
             match clause {
                 Clause::InstallRoot => (),
                 Clause::Excluded(solvable, reason) => {
                     tracing::trace!("{solvable:?} is excluded");
                     let solvable = solvable
-                        .as_solvable(&solver.variable_map)
+                        .as_solvable(&state.variable_map)
                         .expect("only solvables can be excluded");
 
                     let package_node = Self::add_node(&mut graph, &mut nodes, solvable.into());
@@ -80,7 +82,7 @@ impl Conflict {
                 Clause::Learnt(..) => unreachable!(),
                 &Clause::Requires(package_id, version_set_id) => {
                     let solvable = package_id
-                        .as_solvable_or_root(&solver.variable_map)
+                        .as_solvable_or_root(&state.variable_map)
                         .expect("only solvables can be excluded");
                     let package_node = Self::add_node(&mut graph, &mut nodes, solvable);
 
@@ -112,10 +114,10 @@ impl Conflict {
                 }
                 &Clause::Lock(locked, forbidden) => {
                     let locked_solvable = locked
-                        .as_solvable(&solver.variable_map)
+                        .as_solvable(&state.variable_map)
                         .expect("only solvables can be excluded");
                     let forbidden_solvable = forbidden
-                        .as_solvable(&solver.variable_map)
+                        .as_solvable(&state.variable_map)
                         .expect("only solvables can be excluded");
                     let node2_id =
                         Self::add_node(&mut graph, &mut nodes, forbidden_solvable.into());
@@ -124,12 +126,12 @@ impl Conflict {
                 }
                 &Clause::ForbidMultipleInstances(instance1_id, instance2_id, _) => {
                     let solvable1 = instance1_id
-                        .as_solvable_or_root(&solver.variable_map)
+                        .as_solvable_or_root(&state.variable_map)
                         .expect("only solvables can be excluded");
                     let node1_id = Self::add_node(&mut graph, &mut nodes, solvable1);
 
                     let VariableOrigin::ForbidMultiple(name) =
-                        solver.variable_map.origin(instance2_id.variable())
+                        state.variable_map.origin(instance2_id.variable())
                     else {
                         unreachable!("expected only forbid variables")
                     };
@@ -145,10 +147,10 @@ impl Conflict {
                 }
                 &Clause::Constrains(package_id, dep_id, version_set_id) => {
                     let package_solvable = package_id
-                        .as_solvable_or_root(&solver.variable_map)
+                        .as_solvable_or_root(&state.variable_map)
                         .expect("only solvables can be excluded");
                     let dependency_solvable = dep_id
-                        .as_solvable_or_root(&solver.variable_map)
+                        .as_solvable_or_root(&state.variable_map)
                         .expect("only solvables can be excluded");
 
                     let package_node = Self::add_node(&mut graph, &mut nodes, package_solvable);
@@ -496,7 +498,7 @@ impl ConflictGraph {
                     ConflictEdge::Requires(version_set_id) => (version_set_id, e.target()),
                     ConflictEdge::Conflict(_) => unreachable!(),
                 })
-                .chunk_by(|(&version_set_id, _)| version_set_id);
+                .chunk_by(|(version_set_id, _)| *version_set_id);
 
             for (_, mut deps) in &dependencies {
                 if deps.all(|(_, target)| !installable.contains(&target)) {
@@ -542,7 +544,7 @@ impl ConflictGraph {
                     ConflictEdge::Requires(version_set_id) => (version_set_id, e.target()),
                     ConflictEdge::Conflict(_) => unreachable!(),
                 })
-                .chunk_by(|(&version_set_id, _)| version_set_id);
+                .chunk_by(|(version_set_id, _)| *version_set_id);
 
             // Missing if at least one dependency is missing
             if dependencies
@@ -629,42 +631,6 @@ impl Indenter {
     }
 }
 
-#[cfg(test)]
-mod tests {
-    use super::*;
-
-    #[test]
-    fn test_indenter_without_top_level_indent() {
-        let indenter = Indenter::new(false);
-
-        let indenter = indenter.push_level_with_order(ChildOrder::Last);
-        assert_eq!(indenter.get_indent(), "");
-
-        let indenter = indenter.push_level_with_order(ChildOrder::Last);
-        assert_eq!(indenter.get_indent(), "└─ ");
-    }
-
-    #[test]
-    fn test_indenter_with_multiple_siblings() {
-        let indenter = Indenter::new(true);
-
-        let indenter = indenter.push_level_with_order(ChildOrder::Last);
-        assert_eq!(indenter.get_indent(), "└─ ");
-
-        let indenter = indenter.push_level_with_order(ChildOrder::HasRemainingSiblings);
-        assert_eq!(indenter.get_indent(), "   ├─ ");
-
-        let indenter = indenter.push_level_with_order(ChildOrder::Last);
-        assert_eq!(indenter.get_indent(), "   │  └─ ");
-
-        let indenter = indenter.push_level_with_order(ChildOrder::Last);
-        assert_eq!(indenter.get_indent(), "   │     └─ ");
-
-        let indenter = indenter.push_level_with_order(ChildOrder::HasRemainingSiblings);
-        assert_eq!(indenter.get_indent(), "   │        ├─ ");
-    }
-}
-
 /// A struct implementing [`fmt::Display`] that generates a user-friendly
 /// representation of a conflict graph
 pub struct DisplayUnsat<'i, I: Interner> {
@@ -767,7 +733,10 @@ impl<'i, I: Interner> DisplayUnsat<'i, I> {
                                 "{indent}{req} can be installed with any of the following options:"
                             )?;
                         } else {
-                            writeln!(f, "{indent}{req}, which can be installed with any of the following options:")?;
+                            writeln!(
+                                f,
+                                "{indent}{req}, which can be installed with any of the following options:"
+                            )?;
                         }
 
                         let children: Vec<_> = edges
@@ -818,9 +787,15 @@ impl<'i, I: Interner> DisplayUnsat<'i, I> {
                         // Package cannot be installed (the conflicting requirement is further down
                         // the tree)
                         if top_level {
-                            writeln!(f, "{indent}{req} cannot be installed because there are no viable options:")?;
+                            writeln!(
+                                f,
+                                "{indent}{req} cannot be installed because there are no viable options:"
+                            )?;
                         } else {
-                            writeln!(f, "{indent}{req}, which cannot be installed because there are no viable options:")?;
+                            writeln!(
+                                f,
+                                "{indent}{req}, which cannot be installed because there are no viable options:"
+                            )?;
                         }
 
                         let children: Vec<_> = edges
@@ -991,7 +966,7 @@ impl<'i, I: Interner> DisplayUnsat<'i, I> {
     }
 }
 
-impl<'i, I: Interner> fmt::Display for DisplayUnsat<'i, I> {
+impl<I: Interner> fmt::Display for DisplayUnsat<'_, I> {
     fn fmt(&self, f: &mut Formatter<'_>) -> fmt::Result {
         let (top_level_missing, top_level_conflicts): (Vec<_>, _) = self
             .graph
@@ -1052,3 +1027,39 @@ impl<'i, I: Interner> fmt::Display for DisplayUnsat<'i, I> {
         Ok(())
     }
 }
+
+#[cfg(test)]
+mod tests {
+    use super::*;
+
+    #[test]
+    fn test_indenter_without_top_level_indent() {
+        let indenter = Indenter::new(false);
+
+        let indenter = indenter.push_level_with_order(ChildOrder::Last);
+        assert_eq!(indenter.get_indent(), "");
+
+        let indenter = indenter.push_level_with_order(ChildOrder::Last);
+        assert_eq!(indenter.get_indent(), "└─ ");
+    }
+
+    #[test]
+    fn test_indenter_with_multiple_siblings() {
+        let indenter = Indenter::new(true);
+
+        let indenter = indenter.push_level_with_order(ChildOrder::Last);
+        assert_eq!(indenter.get_indent(), "└─ ");
+
+        let indenter = indenter.push_level_with_order(ChildOrder::HasRemainingSiblings);
+        assert_eq!(indenter.get_indent(), "   ├─ ");
+
+        let indenter = indenter.push_level_with_order(ChildOrder::Last);
+        assert_eq!(indenter.get_indent(), "   │  └─ ");
+
+        let indenter = indenter.push_level_with_order(ChildOrder::Last);
+        assert_eq!(indenter.get_indent(), "   │     └─ ");
+
+        let indenter = indenter.push_level_with_order(ChildOrder::HasRemainingSiblings);
+        assert_eq!(indenter.get_indent(), "   │        ├─ ");
+    }
+}
