@@ -148,6 +148,10 @@ extern "C" {
     this: &DenoFsFile,
     len: u32,
   ) -> std::result::Result<(), JsValue>;
+  #[wasm_bindgen(method, structural, js_name = statSync, catch)]
+  fn stat_sync(
+    this: &DenoFsFile,
+  ) -> std::result::Result<JsValue, wasm_bindgen::JsValue>;
   #[wasm_bindgen(method, structural, js_name = isTerminal, catch)]
   fn is_terminal(this: &DenoFsFile) -> std::result::Result<bool, JsValue>;
   #[wasm_bindgen(method, structural, js_name = lockSync, catch)]
@@ -169,12 +173,14 @@ extern "C" {
   fn sync_data_sync(this: &DenoFsFile) -> std::result::Result<(), JsValue>;
 
   // Deno.build
-  #[wasm_bindgen(js_namespace = Deno, js_name = build)]
-  static BUILD: JsValue;
+  #[wasm_bindgen(js_namespace = ["Deno", "build"], js_name = os)]
+  static BUILD_OS: Os;
 
   // Deno.env
-  #[wasm_bindgen(js_namespace = Deno, js_name = env)]
-  static ENV: JsValue;
+  #[wasm_bindgen(js_namespace = ["Deno", "env"], js_name = get, catch)]
+  fn deno_env_get(key: &str) -> std::result::Result<Option<String>, JsValue>;
+  #[wasm_bindgen(js_namespace = ["Deno", "env"], js_name = set, catch)]
+  fn deno_env_set(key: &str, value: &str) -> std::result::Result<(), JsValue>;
 }
 
 #[cfg(all(target_arch = "wasm32", feature = "wasm"))]
@@ -203,12 +209,8 @@ impl BaseEnvSetCurrentDir for RealSys {
 impl BaseEnvVar for RealSys {
   fn base_env_var_os(&self, key: &OsStr) -> Option<OsString> {
     let key = key.to_str()?;
-    let get_fn = js_sys::Reflect::get(&ENV, &JsValue::from_str("get"))
-      .ok()
-      .and_then(|v| v.dyn_into::<js_sys::Function>().ok())?;
-    let key_js = JsValue::from_str(key);
-    let value_js = get_fn.call1(&ENV, &key_js).ok()?;
-    return value_js.as_string().map(OsString::from);
+    let value = deno_env_get(key).ok()?;
+    value.map(OsString::from)
   }
 }
 
@@ -216,13 +218,7 @@ impl BaseEnvSetVar for RealSys {
   fn base_env_set_var(&self, key: &OsStr, value: &OsStr) {
     let key = key.to_str().unwrap();
     let value = value.to_str().unwrap();
-    let set_fn = js_sys::Reflect::get(&ENV, &JsValue::from_str("set"))
-      .ok()
-      .and_then(|v| v.dyn_into::<js_sys::Function>().ok())
-      .unwrap();
-    let key_js = JsValue::from_str(key);
-    let value_js = JsValue::from_str(value);
-    set_fn.call2(&ENV, &key_js, &value_js).unwrap();
+    deno_env_set(key, value).unwrap();
   }
 }
 
@@ -240,14 +236,14 @@ impl EnvSetUmask for RealSys {
 
 impl EnvCacheDir for RealSys {
   fn env_cache_dir(&self) -> Option<PathBuf> {
-    match build_os() {
-      Os::Linux => self
-        .env_var_path("XDG_CACHE_HOME")
-        .or_else(|| self.env_home_dir().map(|home| home.join(".cache"))),
-      Os::Mac => self.env_home_dir().map(|h| h.join("Library/Caches")),
+    match *BUILD_OS {
       Os::Windows => self
         .env_var_path("USERPROFILE")
         .map(|dir| dir.join("AppData/Local")),
+      Os::Darwin => self.env_home_dir().map(|h| h.join("Library/Caches")),
+      _ => self
+        .env_var_path("XDG_CACHE_HOME")
+        .or_else(|| self.env_home_dir().map(|home| home.join(".cache"))),
     }
   }
 }
@@ -262,6 +258,18 @@ impl EnvHomeDir for RealSys {
   }
 }
 
+impl EnvProgramsDir for RealSys {
+  fn env_programs_dir(&self) -> Option<PathBuf> {
+    if is_windows() {
+      self
+        .env_var_path("LOCALAPPDATA")
+        .map(|dir| dir.join("Programs"))
+    } else {
+      None
+    }
+  }
+}
+
 impl EnvTempDir for RealSys {
   fn env_temp_dir(&self) -> std::io::Result<PathBuf> {
     node_tmpdir()
@@ -369,6 +377,16 @@ impl BaseFsHardLink for RealSys {
   }
 }
 
+impl BaseFsCreateJunction for RealSys {
+  fn base_fs_create_junction(
+    &self,
+    original: &Path,
+    junction: &Path,
+  ) -> io::Result<()> {
+    deno_symlink_sync_with_type(original, junction, "junction")
+  }
+}
+
 impl From<&JsValue> for FileType {
   fn from(value: &JsValue) -> Self {
     let is_file = js_sys::Reflect::get(value, &JsValue::from_str("isFile"))
@@ -700,7 +718,7 @@ impl BaseFsReadDir for RealSys {
     &self,
     path: &Path,
   ) -> std::io::Result<
-    Box<dyn Iterator<Item = std::io::Result<Self::ReadDirEntry>> + '_>,
+    Box<dyn Iterator<Item = std::io::Result<Self::ReadDirEntry>>>,
   > {
     let path_str = wasm_path_to_str(path);
 
@@ -867,24 +885,7 @@ impl BaseFsSymlinkDir for RealSys {
     original: &Path,
     link: &Path,
   ) -> std::io::Result<()> {
-    let old_path = wasm_path_to_str(original);
-    let new_path = wasm_path_to_str(link);
-
-    // Create an options object for Deno.symlinkSync specifying a directory symlink
-    let options = js_sys::Object::new();
-    js_sys::Reflect::set(
-      &options,
-      &wasm_bindgen::JsValue::from_str("type"),
-      &wasm_bindgen::JsValue::from_str("dir"),
-    )
-    .map_err(js_value_to_io_error)?;
-
-    deno_symlink_sync(
-      &old_path,
-      &new_path,
-      &wasm_bindgen::JsValue::from(options),
-    )
-    .map_err(js_value_to_io_error)
+    deno_symlink_sync_with_type(original, link, "dir")
   }
 }
 
@@ -894,27 +895,31 @@ impl BaseFsSymlinkFile for RealSys {
     original: &Path,
     link: &Path,
   ) -> std::io::Result<()> {
-    let old_path = wasm_path_to_str(original);
-    let new_path = wasm_path_to_str(link);
-
-    // Create an options object for Deno.symlinkSync specifying a file symlink
-    let options = js_sys::Object::new();
-    js_sys::Reflect::set(
-      &options,
-      &wasm_bindgen::JsValue::from_str("type"),
-      &wasm_bindgen::JsValue::from_str("file"),
-    )
-    .map_err(js_value_to_io_error)?;
-
-    deno_symlink_sync(
-      &old_path,
-      &new_path,
-      &wasm_bindgen::JsValue::from(options),
-    )
-    .map_err(js_value_to_io_error)
+    deno_symlink_sync_with_type(original, link, "file")
   }
 }
 
+fn deno_symlink_sync_with_type(
+  original: &Path,
+  link: &Path,
+  type_str: &'static str,
+) -> std::io::Result<()> {
+  let old_path = wasm_path_to_str(original);
+  let new_path = wasm_path_to_str(link);
+
+  // Create an options object for Deno.symlinkSync specifying the type of symlink
+  let options = js_sys::Object::new();
+  js_sys::Reflect::set(
+    &options,
+    &wasm_bindgen::JsValue::from_str("type"),
+    &wasm_bindgen::JsValue::from_str(type_str),
+  )
+  .map_err(js_value_to_io_error)?;
+
+  deno_symlink_sync(&old_path, &new_path, &wasm_bindgen::JsValue::from(options))
+    .map_err(js_value_to_io_error)
+}
+
 impl BaseFsWrite for RealSys {
   fn base_fs_write(&self, path: &Path, data: &[u8]) -> std::io::Result<()> {
     let s = wasm_path_to_str(path);
@@ -979,6 +984,16 @@ impl FsFileSetLen for WasmFile {
   }
 }
 
+impl FsFileMetadata for WasmFile {
+  fn fs_file_metadata(&self) -> io::Result<BoxedFsMetadataValue> {
+    self
+      .file
+      .stat_sync()
+      .map(|m| BoxedFsMetadataValue::new(WasmMetadata(m)))
+      .map_err(js_value_to_io_error)
+  }
+}
+
 impl FsFileSetPermissions for WasmFile {
   fn fs_file_set_permissions(&mut self, mode: u32) -> std::io::Result<()> {
     if is_windows() {
@@ -1109,30 +1124,16 @@ impl crate::ThreadSleep for RealSys {
 
 #[cfg(all(target_arch = "wasm32", feature = "wasm"))]
 #[inline]
-pub(super) fn is_windows() -> bool {
-  build_os() == Os::Windows
+pub fn is_windows() -> bool {
+  *BUILD_OS == Os::Windows
 }
 
 #[cfg(all(target_arch = "wasm32", feature = "wasm"))]
+#[wasm_bindgen]
 #[derive(Debug, Clone, Copy, PartialEq, Eq)]
-pub(super) enum Os {
-  Windows,
-  Mac,
-  Linux,
-}
-
-#[cfg(all(target_arch = "wasm32", feature = "wasm"))]
-pub(super) fn build_os() -> Os {
-  static BUILD_OS: std::sync::OnceLock<Os> = std::sync::OnceLock::new();
-
-  *BUILD_OS.get_or_init(|| {
-    let os = js_sys::Reflect::get(&BUILD, &JsValue::from_str("os")).unwrap();
-    match os.as_string().unwrap().as_str() {
-      "windows" => Os::Windows,
-      "mac" => Os::Mac,
-      _ => Os::Linux,
-    }
-  })
+enum Os {
+  Windows = "windows",
+  Darwin = "darwin",
 }
 
 fn js_value_to_io_error(js_value: wasm_bindgen::JsValue) -> Error {
